0.1
----------

- First tagged version

0.2
----------

- with trivial tests

0.3
----------

- with 2D plotting

0.3.1
----------

- Source names in output files

0.3.2
----------

- Refactor to fix trace centroids

0.3.3
----------

- bugs

0.3.4
----------

- center drizzled product

0.3.5
----------

- bug fixes for glass

0.3.6
----------

- bug fixes for glass

0.3.7
----------

- Refactor setup scripts (https://github.com/gbrammer/msaexp/pull/9)

0.3.13
----------

- Add CI tests for spectrum extraction and fitting